<p align="center" >
<img src=".github/branding/dragon.svg" alt="Logo" width=200px> 
</p>
<p align="center">
  <strong>
  dragon is an expansible build system built for speed and ease of use.
  </strong>
  <br>
  <br>
  <a href="https://github.com/dragonbuild/dragon/actions/workflows/tests.yml">
    <image src="https://github.com/dragonbuild/dragon/actions/workflows/tests.yml/badge.svg">
  </a>
  <a href="https://dragon.rtfd.io">
    <image src="https://readthedocs.org/projects/dragon/badge/?version=latest">
  </a>
  <a href="https://pypi.org/project/dragon/">
    <image src="https://pypip.in/v/dragon/badge.svg">
  </a>
</p>

# Installing dragon

In your terminal:

`pip3 install dragon`
  
## Updating
    
Version 1.6.0 and later:
    
```sh
dragon update
```
    
Version 1.5.1 and older:
  
```sh
rm -rf ~/.dragon
pip3 install --force-reinstall dragon
```

---

## Documentation
    
https://dragon.rtfd.io/
    
## Quickstart Guide
    
https://dragon.readthedocs.io/en/latest/quickstart.html
    
## Example Project
    
https://github.com/dragonbuild/example 
    
# Helpful links

[sbingner's arm64e toolchain](https://github.com/sbingner/llvm-project/releases/latest)
